@@ -40,16 +40,16 @@ def debug(request):
 
     elif action == 'deactivate':
         # выключение отладчика
-        response.set_cookie('debug_on', False)
+        response.delete_cookie('debug_on')
 
     elif (action == 'delete'
-          and 'debug_file_path' in request.session
-          and os.path.exists(request.session['debug_file_path'])):
+          and 'debug_file_path' in request.COOKIES
+          and os.path.exists(request.COOKIES['debug_file_path'])):
         # удаление файла дампа
-        os.remove(request.session['debug_file_path'])
+        os.remove(request.COOKIES['debug_file_path'])
         response.set_cookie('debug_on', False)
-        response.del_cookie('debug_file_path')
-        response.del_cookie('debug_file_url')
+        response.delete_cookie('debug_file_path')
+        response.delete_cookie('debug_file_url')
     elif action == 'dump_data':
         # выгрузка дампа БД
         buf = StringIO()
